@@ -12,5 +12,6 @@ def test_suite():
         ztc.ZopeDocFileSuite(
             'README.txt', package='collective.geo.settings',
             test_class=base.FunctionalTestCase,
-            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE | doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS),
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE | \
+                    doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS),
         ])
